All of lore.kernel.org
 help / color / mirror / Atom feed
From: Jinjie Ruan via <qemu-devel@nongnu.org>
To: <peter.maydell@linaro.org>, <eduardo@habkost.net>,
	<marcel.apfelbaum@gmail.com>, <philmd@linaro.org>,
	<wangyanan55@huawei.com>, <richard.henderson@linaro.org>,
	<qemu-devel@nongnu.org>, <qemu-arm@nongnu.org>
Cc: <ruanjinjie@huawei.com>
Subject: [PATCH v11 10/23] hw/arm/virt: Wire NMI and VINMI irq lines from GIC to CPU
Date: Sat, 30 Mar 2024 10:31:15 +0000	[thread overview]
Message-ID: <20240330103128.3185962-11-ruanjinjie@huawei.com> (raw)
In-Reply-To: <20240330103128.3185962-1-ruanjinjie@huawei.com>

Wire the new NMI and VINMI interrupt line from the GIC to each CPU.

Signed-off-by: Jinjie Ruan <ruanjinjie@huawei.com>
Reviewed-by: Richard Henderson <richard.henderson@linaro.org>
---
v9:
- Rename ARM_CPU_VNMI to ARM_CPU_VINMI.
- Update the commit message.
v4:
- Add Reviewed-by.
v3:
- Also add VNMI wire.
---
 hw/arm/virt.c | 7 ++++++-
 1 file changed, 6 insertions(+), 1 deletion(-)

diff --git a/hw/arm/virt.c b/hw/arm/virt.c
index a9a913aead..ef2e6c2c4d 100644
--- a/hw/arm/virt.c
+++ b/hw/arm/virt.c
@@ -821,7 +821,8 @@ static void create_gic(VirtMachineState *vms, MemoryRegion *mem)
 
     /* Wire the outputs from each CPU's generic timer and the GICv3
      * maintenance interrupt signal to the appropriate GIC PPI inputs,
      * and the GIC's IRQ/FIQ/VIRQ/VFIQ interrupt outputs to the CPU's inputs.
      */
     for (i = 0; i < smp_cpus; i++) {
         DeviceState *cpudev = DEVICE(qemu_get_cpu(i));
@@ -865,6 +866,10 @@ static void create_gic(VirtMachineState *vms, MemoryRegion *mem)
                            qdev_get_gpio_in(cpudev, ARM_CPU_VIRQ));
         sysbus_connect_irq(gicbusdev, i + 3 * smp_cpus,
                            qdev_get_gpio_in(cpudev, ARM_CPU_VFIQ));
+        sysbus_connect_irq(gicbusdev, i + 4 * smp_cpus,
+                           qdev_get_gpio_in(cpudev, ARM_CPU_NMI));
+        sysbus_connect_irq(gicbusdev, i + 5 * smp_cpus,
+                           qdev_get_gpio_in(cpudev, ARM_CPU_VINMI));
     }
 
     fdt_add_gic_node(vms);
@@ -821,7 +821,8 @@ static void create_gic(VirtMachineState *vms, MemoryRegion *mem)
     /* Wire the outputs from each CPU's generic timer and the GICv3
      * maintenance interrupt signal to the appropriate GIC PPI inputs,
-     * and the GIC's IRQ/FIQ/VIRQ/VFIQ interrupt outputs to the CPU's inputs.
+     * and the GIC's IRQ/FIQ/VIRQ/VFIQ/NMI/VINMI interrupt outputs to the
+     * CPU's inputs.
      */
     for (i = 0; i < smp_cpus; i++) {
-- 
2.34.1



  parent reply	other threads:[~2024-03-30 10:35 UTC|newest]

Thread overview: 35+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2024-03-30 10:31 [PATCH v11 00/23] target/arm: Implement FEAT_NMI and FEAT_GICv3_NMI Jinjie Ruan via
2024-03-30 10:31 ` [PATCH v11 01/23] target/arm: Handle HCR_EL2 accesses for bits introduced with FEAT_NMI Jinjie Ruan via
2024-03-30 10:31 ` [PATCH v11 02/23] target/arm: Add PSTATE.ALLINT Jinjie Ruan via
2024-03-30 10:31 ` [PATCH v11 03/23] target/arm: Add support for FEAT_NMI, Non-maskable Interrupt Jinjie Ruan via
2024-03-30 10:31 ` [PATCH v11 04/23] target/arm: Implement ALLINT MSR (immediate) Jinjie Ruan via
2024-03-30 10:31 ` [PATCH v11 05/23] target/arm: Support MSR access to ALLINT Jinjie Ruan via
2024-03-30 10:31 ` [PATCH v11 06/23] target/arm: Add support for Non-maskable Interrupt Jinjie Ruan via
2024-03-30 10:31 ` [PATCH v11 07/23] target/arm: Add support for NMI in arm_phys_excp_target_el() Jinjie Ruan via
2024-03-30 10:31 ` [PATCH v11 08/23] target/arm: Handle IS/FS in ISR_EL1 for NMI, VINMI and VFNMI Jinjie Ruan via
2024-03-30 10:31 ` [PATCH v11 09/23] target/arm: Handle PSTATE.ALLINT on taking an exception Jinjie Ruan via
2024-03-30 10:31 ` Jinjie Ruan via [this message]
2024-03-30 10:31 ` [PATCH v11 11/23] hw/intc/arm_gicv3: Add external IRQ lines for NMI Jinjie Ruan via
2024-03-30 10:31 ` [PATCH v11 12/23] target/arm: Handle NMI in arm_cpu_do_interrupt_aarch64() Jinjie Ruan via
2024-03-30 10:31 ` [PATCH v11 13/23] hw/intc: Enable FEAT_GICv3_NMI Feature Jinjie Ruan via
2024-04-02 16:25   ` Peter Maydell
2024-03-30 10:31 ` [PATCH v11 14/23] hw/intc/arm_gicv3: Add irq non-maskable property Jinjie Ruan via
2024-04-02 16:20   ` Peter Maydell
2024-03-30 10:31 ` [PATCH v11 15/23] hw/intc/arm_gicv3_redist: Implement GICR_INMIR0 Jinjie Ruan via
2024-03-30 10:31 ` [PATCH v11 16/23] hw/intc/arm_gicv3: Implement GICD_INMIR Jinjie Ruan via
2024-03-30 10:31 ` [PATCH v11 17/23] hw/intc/arm_gicv3: Add NMI handling CPU interface registers Jinjie Ruan via
2024-04-02 16:05   ` Peter Maydell
2024-03-30 10:31 ` [PATCH v11 18/23] hw/intc/arm_gicv3: Handle icv_nmiar1_read() for icc_nmiar1_read() Jinjie Ruan via
2024-04-02 16:12   ` Peter Maydell
2024-04-03  2:21     ` Jinjie Ruan via
2024-04-03  3:16     ` Jinjie Ruan via
2024-04-03 11:49       ` Peter Maydell
2024-03-30 10:31 ` [PATCH v11 19/23] hw/intc/arm_gicv3: Implement NMI interrupt prioirty Jinjie Ruan via
2024-04-02 16:16   ` Peter Maydell
2024-03-30 10:31 ` [PATCH v11 20/23] hw/intc/arm_gicv3: Report the NMI interrupt in gicv3_cpuif_update() Jinjie Ruan via
2024-04-02 16:16   ` Peter Maydell
2024-03-30 10:31 ` [PATCH v11 21/23] hw/intc/arm_gicv3: Report the VINMI interrupt Jinjie Ruan via
2024-04-02 16:17   ` Peter Maydell
2024-03-30 10:31 ` [PATCH v11 22/23] target/arm: Add FEAT_NMI to max Jinjie Ruan via
2024-04-02 16:18   ` Peter Maydell
2024-03-30 10:31 ` [PATCH v11 23/23] hw/arm/virt: Add FEAT_GICv3_NMI feature support in virt GIC Jinjie Ruan via

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20240330103128.3185962-11-ruanjinjie@huawei.com \
    --to=qemu-devel@nongnu.org \
    --cc=eduardo@habkost.net \
    --cc=marcel.apfelbaum@gmail.com \
    --cc=peter.maydell@linaro.org \
    --cc=philmd@linaro.org \
    --cc=qemu-arm@nongnu.org \
    --cc=richard.henderson@linaro.org \
    --cc=ruanjinjie@huawei.com \
    --cc=wangyanan55@huawei.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.